@@ -34,6 +34,7 @@ from cognite_toolkit._cdf_tk.apps import (
     PurgeApp,
     RepoApp,
     RunApp,
+    UploadApp,
 )
 from cognite_toolkit._cdf_tk.cdf_toml import CDFToml
 from cognite_toolkit._cdf_tk.commands import (
@@ -112,6 +113,9 @@ if Flags.MIGRATE.is_enabled():
 if Flags.DOWNLOAD.is_enabled():
     _app.add_typer(DownloadApp(**default_typer_kws), name="download")
 
+if Flags.UPLOAD.is_enabled():
+    _app.add_typer(UploadApp(**default_typer_kws), name="upload")
+
 _app.add_typer(ModulesApp(**default_typer_kws), name="modules")
 _app.command("init")(landing_app.main_init)
 
