@@ -16,7 +16,9 @@ from cognite_toolkit._cdf_tk.commands.dump_data import (
 from cognite_toolkit._cdf_tk.commands.dump_resource import (
     AgentFinder,
     DataModelFinder,
+    DataSetFinder,
     ExtractionPipelineFinder,
+    FunctionFinder,
     GroupFinder,
     LocationFilterFinder,
     NodeFinder,
@@ -55,6 +57,8 @@ class DumpApp(typer.Typer):
             if Flags.DUMP_EXTENDED.is_enabled():
                 self.command("location-filter")(DumpConfigApp.dump_location_filters)
                 self.command("extraction-pipeline")(DumpConfigApp.dump_extraction_pipeline)
+                self.command("functions")(DumpConfigApp.dump_functions)
+                self.command("datasets")(DumpConfigApp.dump_datasets)
 
             if Flags.AGENTS.is_enabled() and Flags.DUMP_EXTENDED.is_enabled():
                 self.command("agents")(DumpConfigApp.dump_agents)
@@ -80,6 +84,8 @@ class DumpConfigApp(typer.Typer):
         if Flags.DUMP_EXTENDED.is_enabled():
             self.command("location-filters")(self.dump_location_filters)
             self.command("extraction-pipeline")(self.dump_extraction_pipeline)
+            self.command("datasets")(DumpConfigApp.dump_datasets)
+            self.command("functions")(self.dump_functions)
         if Flags.DUMP_EXTENDED.is_enabled() and Flags.AGENTS.is_enabled():
             self.command("agents")(self.dump_agents)
 
@@ -514,6 +520,102 @@ class DumpConfigApp(typer.Typer):
             )
         )
 
+    @staticmethod
+    def dump_datasets(
+        ctx: typer.Context,
+        external_id: Annotated[
+            list[str] | None,
+            typer.Argument(
+                help="The external ID(s) of the datasets you want to dump. "
+                "If nothing is provided, an interactive prompt will be shown to select the datasets.",
+            ),
+        ] = None,
+        output_dir: Annotated[
+            Path,
+            typer.Option(
+                "--output-dir",
+                "-o",
+                help="Where to dump the dataset files.",
+                allow_dash=True,
+            ),
+        ] = Path("tmp"),
+        clean: Annotated[
+            bool,
+            typer.Option(
+                "--clean",
+                "-c",
+                help="Delete the output directory before dumping the datasets.",
+            ),
+        ] = False,
+        verbose: Annotated[
+            bool,
+            typer.Option(
+                "--verbose",
+                "-v",
+                help="Turn on to get more verbose output when running the command",
+            ),
+        ] = False,
+    ) -> None:
+        """This command will dump the selected datasets as yaml to the folder specified, defaults to /tmp."""
+        client = EnvironmentVariables.create_from_environment().get_client()
+        cmd = DumpResourceCommand()
+        cmd.run(
+            lambda: cmd.dump_to_yamls(
+                DataSetFinder(client, tuple(external_id) if external_id else None),
+                output_dir=output_dir,
+                clean=clean,
+                verbose=verbose,
+            )
+        )
+
+    @staticmethod
+    def dump_functions(
+        ctx: typer.Context,
+        external_id: Annotated[
+            list[str] | None,
+            typer.Argument(
+                help="The external ID(s) of the functions you want to dump. "
+                "If nothing is provided, an interactive prompt will be shown to select the functions.",
+            ),
+        ] = None,
+        output_dir: Annotated[
+            Path,
+            typer.Option(
+                "--output-dir",
+                "-o",
+                help="Where to dump the function files.",
+                allow_dash=True,
+            ),
+        ] = Path("tmp"),
+        clean: Annotated[
+            bool,
+            typer.Option(
+                "--clean",
+                "-c",
+                help="Delete the output directory before dumping the functions.",
+            ),
+        ] = False,
+        verbose: Annotated[
+            bool,
+            typer.Option(
+                "--verbose",
+                "-v",
+                help="Turn on to get more verbose output when running the command",
+            ),
+        ] = False,
+    ) -> None:
+        """This command will dump the selected functions as yaml to the folder specified, defaults to /tmp."""
+        client = EnvironmentVariables.create_from_environment().get_client()
+        cmd = DumpResourceCommand()
+        cmd.run(
+            lambda: cmd.dump_to_yamls(
+                FunctionFinder(client, tuple(external_id) if external_id else None),
+                output_dir=output_dir,
+                clean=clean,
+                verbose=verbose,
+            )
+        )
+
 
 class DumpDataApp(typer.Typer):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
