@@ -9,6 +9,7 @@ from ._migrate import (
 from ._populate import PopulateCommand
 from ._profile import ProfileAssetCentricCommand, ProfileAssetCommand, ProfileRawCommand, ProfileTransformationCommand
 from ._purge import PurgeCommand
+from ._upload import UploadCommand
 from .auth import AuthCommand
 from .build_cmd import BuildCommand
 from .clean import CleanCommand
@@ -51,4 +52,5 @@ __all__ = [
     "RunFunctionCommand",
     "RunTransformationCommand",
     "RunWorkflowCommand",
+    "UploadCommand",
 ]
