@@ -1,3 +1,5 @@
+import io
+import zipfile
 from abc import ABC, abstractmethod
 from collections import defaultdict
 from collections.abc import Hashable, Iterable, Iterator
@@ -9,6 +11,7 @@ import questionary
 import typer
 from cognite.client import data_modeling as dm
 from cognite.client.data_classes import (
+    DataSetList,
     ExtractionPipelineList,
     Group,
     GroupList,
@@ -24,6 +27,11 @@ from cognite.client.data_classes.agents import (
 )
 from cognite.client.data_classes.data_modeling import DataModelId
 from cognite.client.data_classes.extractionpipelines import ExtractionPipelineConfigList
+from cognite.client.data_classes.functions import (
+    Function,
+    FunctionList,
+    FunctionSchedulesList,
+)
 from cognite.client.data_classes.workflows import (
     Workflow,
     WorkflowList,
@@ -49,8 +57,11 @@ from cognite_toolkit._cdf_tk.loaders import (
     AgentLoader,
     ContainerLoader,
     DataModelLoader,
+    DataSetsLoader,
     ExtractionPipelineConfigLoader,
     ExtractionPipelineLoader,
+    FunctionLoader,
+    FunctionScheduleLoader,
     GroupLoader,
     LocationFilterLoader,
     NodeLoader,
@@ -65,9 +76,9 @@ from cognite_toolkit._cdf_tk.loaders import (
     WorkflowVersionLoader,
 )
 from cognite_toolkit._cdf_tk.loaders._base_loaders import T_ID
-from cognite_toolkit._cdf_tk.tk_warnings import FileExistsWarning, MediumSeverityWarning
+from cognite_toolkit._cdf_tk.tk_warnings import FileExistsWarning, HighSeverityWarning, MediumSeverityWarning
 from cognite_toolkit._cdf_tk.utils import humanize_collection
-from cognite_toolkit._cdf_tk.utils.file import safe_rmtree, safe_write, yaml_safe_dump
+from cognite_toolkit._cdf_tk.utils.file import safe_rmtree, safe_write, to_directory_compatible, yaml_safe_dump
 
 from ._base import ToolkitCommand
 
@@ -490,6 +501,102 @@ class ExtractionPipelineFinder(ResourceFinder[tuple[str, ...]]):
         yield [], configs, config_loader, None
 
 
+class DataSetFinder(ResourceFinder[tuple[str, ...]]):
+    """Finds data sets to dump."""
+
+    def __init__(self, client: ToolkitClient, identifier: tuple[str, ...] | None = None):
+        super().__init__(client, identifier)
+        self.datasets: DataSetList | None = None
+
+    def _interactive_select(self) -> tuple[str, ...]:
+        self.datasets = self.client.data_sets.list(limit=-1)
+        if not self.datasets:
+            raise ToolkitMissingResourceError("No datasets found")
+        choices = [
+            Choice(f"{dataset.name} ({dataset.external_id})", value=dataset.external_id)
+            for dataset in sorted(self.datasets, key=lambda d: d.name or "")
+            if dataset.external_id
+        ]
+        selected_dataset_ids: tuple[str, ...] | None = questionary.checkbox(
+            "Which dataset(s) would you like to dump?",
+            choices=choices,
+        ).ask()
+        if selected_dataset_ids is None:
+            raise ToolkitValueError("No datasets selected for dumping.")
+        return tuple(selected_dataset_ids)
+
+    def __iter__(self) -> Iterator[tuple[list[Hashable], CogniteResourceList | None, ResourceLoader, None | str]]:
+        self.identifier = self._selected()
+        loader = DataSetsLoader.create_loader(self.client)
+        if self.datasets:
+            yield (
+                [],
+                DataSetList([d for d in self.datasets if d.external_id in set(self.identifier)]),
+                loader,
+                None,
+            )
+        else:
+            yield list(self.identifier), None, loader, None
+
+
+class FunctionFinder(ResourceFinder[tuple[str, ...]]):
+    def __init__(self, client: ToolkitClient, identifier: tuple[str, ...] | None = None):
+        super().__init__(client, identifier)
+        self.functions: FunctionList | None = None
+
+    def _interactive_select(self) -> tuple[str, ...]:
+        self.functions = self.client.functions.list(limit=-1)
+        if not self.functions:
+            raise ToolkitMissingResourceError("No functions found")
+        choices = [
+            Choice(f"{function.name} ({function.external_id})", value=function.external_id)
+            for function in sorted(self.functions, key=lambda f: f.name or "")
+            if function.name and function.external_id
+        ]
+        selected_function_ids: tuple[str, ...] | None = questionary.checkbox(
+            "Which function(s) would you like to dump?",
+            choices=choices,
+        ).ask()
+        if selected_function_ids is None:
+            raise ToolkitValueError("No functions selected for dumping.")
+        return tuple(selected_function_ids)
+
+    def __iter__(self) -> Iterator[tuple[list[Hashable], CogniteResourceList | None, ResourceLoader, None | str]]:
+        self.identifier = self._selected()
+        loader = FunctionLoader.create_loader(self.client)
+        if self.functions:
+            selected_functions = FunctionList([f for f in self.functions if f.external_id in self.identifier])
+            yield [], selected_functions, loader, None
+        else:
+            yield list(self.identifier), None, loader, None
+
+        schedule_loader = FunctionScheduleLoader.create_loader(self.client)
+        schedules = schedule_loader.iterate(parent_ids=list(self.identifier))
+        yield [], FunctionSchedulesList(list(schedules)), schedule_loader, None
+
+    def dump_function_code(self, function: Function, folder: Path) -> None:
+        try:
+            zip_bytes = self.client.files.download_bytes(id=function.file_id)
+        except CogniteAPIError as e:
+            if e.code == 400 and "File ids not found" in e.message:
+                HighSeverityWarning(
+                    f"The function {function.external_id!r} does not have code to dump. It is not available in CDF."
+                ).print_warning()
+                return
+            raise
+        try:
+            top_level = f"{to_directory_compatible(function.external_id or 'unknown_external_id')}/"
+            with zipfile.ZipFile(io.BytesIO(zip_bytes)) as zf:
+                if all(name.startswith(top_level) for name in zf.namelist()):
+                    zf.extractall(folder)
+                else:
+                    zf.extractall(folder / top_level)
+        except zipfile.BadZipFile as e:
+            HighSeverityWarning(
+                f"The function {function.external_id!r} has a corrupted code zip file. Unable to extract code: {e!s}"
+            ).print_warning()
+
+
 class DumpResourceCommand(ToolkitCommand):
     def dump_to_yamls(
         self,
@@ -539,5 +646,7 @@ class DumpResourceCommand(ToolkitCommand):
                     safe_write(filepath, content, encoding="utf-8")
                     if verbose:
                         self.console(f"Dumped {loader.kind} {name} to {filepath!s}")
+                if isinstance(finder, FunctionFinder) and isinstance(resource, Function):
+                    finder.dump_function_code(resource, resource_folder)
 
         print(Panel(f"Dumped {finder.identifier}", title="Success", style="green", expand=False))
