@@ -732,8 +732,8 @@ class ViewLoader(ResourceLoader[ViewId, ViewApply, View, ViewApplyList, ViewList
             try:
                 created = self.client.data_modeling.views.apply(item)
             except CogniteAPIError as e2:
-                e2.failed.extend(items[no + 1 :])
-                e2.successful.extend(created_list)
+                e2.failed = tuple(e2.failed) + tuple(items[no + 1 :])
+                e2.successful = tuple(e2.successful) + tuple(created_list)
                 raise e2 from e1
             else:
                 created_list.append(created)
