@@ -8,15 +8,21 @@ from ._compression import (
 )
 from ._readers import (
     FILE_READ_CLS_BY_FORMAT,
+    CSVReader,
+    FailedParsing,
     FileReader,
     NDJsonReader,
+    ParquetReader,
     YAMLReader,
     YMLReader,
 )
 from ._writers import (
     FILE_WRITE_CLS_BY_FORMAT,
+    TABLE_WRITE_CLS_BY_FORMAT,
+    CSVWriter,
     FileWriter,
     NDJsonWriter,
+    ParquetWriter,
     YAMLWriter,
     YMLWriter,
 )
@@ -26,15 +32,21 @@ __all__ = [
     "COMPRESSION_BY_SUFFIX",
     "FILE_READ_CLS_BY_FORMAT",
     "FILE_WRITE_CLS_BY_FORMAT",
+    "TABLE_WRITE_CLS_BY_FORMAT",
+    "CSVReader",
+    "CSVWriter",
     "CellValue",
     "Chunk",
     "Compression",
     "DataType",
+    "FailedParsing",
     "FileReader",
     "FileWriter",
     "GzipCompression",
     "NDJsonReader",
     "NDJsonWriter",
+    "ParquetReader",
+    "ParquetWriter",
     "PrimaryCellValue",
     "SchemaColumn",
     "Uncompressed",
